pub unsafe fn DStorageGetFactory<T: Interface>() -> Result<T>Expand description
Runtime-loaded variant of crate::DStorageGetFactory() from dstorage.dll
Safety
Loads a raw pointer from dstorage.dll and casts it to a function to call.
pub unsafe fn DStorageGetFactory<T: Interface>() -> Result<T>Runtime-loaded variant of crate::DStorageGetFactory() from dstorage.dll
Loads a raw pointer from dstorage.dll and casts it to a function to call.